import { useAjax } from "@/Hook/useAjax"
import TableData from "@/pages/launchSystemNew/components/TableData"
import { getSysWarningRuleListApi } from "@/services/adMonitor/earlyWarning"
import { Button, Drawer, Form, Input, Modal, Space } from "antd"
import React, { useEffect, useState } from "react"
import AddEdit from "./addEdit"
import tableConfig from "./tableConfig"



/**
 * 监控预警
 * @returns 
 */
const EarlyWarning: React.FC = () => {

    /**************************/
    const [visible, setVisible] = useState<boolean>(true)
    const [addVisible, setAddVisible] = useState<boolean>(false)
    const [queryParams, setQueryParams] = useState<{ ruleName?: string }>({})

    const getSysWarningRuleList = useAjax((params) => getSysWarningRuleListApi(params))
    /**************************/

    // 获取列表
    useEffect(() => {
        getList()
    }, [])

    const getList = () => {
        getSysWarningRuleList.run(queryParams)
    }

    return <>
        <Button type="primary" onClick={() => setVisible(true)}>监控预警</Button>

        {/* 预警列表 */}
        {visible && <Drawer
            title="监控预警"
            placement="right"
            onClose={() => setVisible(false)}
            visible={visible}
            width='800px'
        >
            <Space direction="vertical">
                <Space>
                    <Input placeholder="请输入规则名字" value={queryParams?.ruleName} onChange={(e) => setQueryParams({ ...queryParams, ruleName: e.target.value })} />
                    <Button type="primary" onClick={getList}>搜索</Button>
                    <Button type="primary" onClick={() => setAddVisible(true)}>设置预警</Button>
                </Space>

                <TableData
                    isCard={false}
                    columns={() => tableConfig()}
                    ajax={getSysWarningRuleList}
                    dataSource={getSysWarningRuleList?.data}
                    loading={getSysWarningRuleList?.loading}
                    scroll={{ y: 560 }}
                    total={getSysWarningRuleList?.data?.length}
                    gutter={[0, 10]}
                    leftChild={<Space direction='vertical'>

                    </Space>}
                />
            </Space>
        </Drawer>}

        {/* 设置预警 */}
        {addVisible && <AddEdit visible={addVisible} onClose={() => setAddVisible(false)} />}
    </>
}

export default React.memo(EarlyWarning)